==> imsdk_client_flutter-0.0.7.tar.gz: lib/app/userme_settings.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart';

import 'app_config.dart';
import 'app_locale.dart';
import 'app_router.dart';
import 'widget/widget_dialog.dart';
import 'widget/widget_divider.dart';

///
///个人中心设置页
///
class UsermeSettings extends StatefulWidget {
  ///标题
  final String title;

  const UsermeSettings({Key? key, required this.title}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _UsermeSettingsState();
}

class _UsermeSettingsState extends State<UsermeSettings> {
  @override
  void initState() {
    super.initState();
    AppConfig.logDebug(['UsermeSettings.initState()']);
    AppConfig.client.setOnUserUpdateListener(_onUserUpdateListener, remove: false);
  }

  @override
  void dispose() {
    AppConfig.logDebug(['UsermeSettings.dispose()']);
    AppConfig.client.setOnUserUpdateListener(_onUserUpdateListener, remove: true);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    return Scaffold(
      appBar: _buildAppBar(themeData),
      body: _buildBody(themeData),
    );
  }

  AppBar _buildAppBar(ThemeData themeData) {
    return AppBar(
      title: Text(widget.title),
    );
  }

  Widget _buildBody(ThemeData themeData) {
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserByfind, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.byfind, onChanged: (value) => _onUserSettingsByFindItemTap()),
                onTap: _onUserSettingsByFindItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserBycode, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.bycode, onChanged: (value) => _onUserSettingsByCodeItemTap()),
                onTap: _onUserSettingsByCodeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserBycard, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.bycard, onChanged: (value) => _onUserSettingsByCardItemTap()),
                onTap: _onUserSettingsByCardItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserByteam, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.byteam, onChanged: (value) => _onUserSettingsByTeamItemTap()),
                onTap: _onUserSettingsByTeamItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserNotice, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.notice, onChanged: (value) => _onUserSettingsNoticeItemTap()),
                onTap: _onUserSettingsNoticeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserSlient, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: !AppConfig.client.user.silent, onChanged: (value) => _onUserSettingsSlientItemTap()),
                onTap: _onUserSettingsSlientItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    const Icon(Icons.power_settings_new_outlined, color: Colors.redAccent, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.usermeSettingsBtnLogout, style: themeData.textTheme.subtitle1?.copyWith(color: Colors.redAccent)),
                  ],
                ),
                onTap: _onUserLogoutBtnTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  void _onUserSettingsByFindItemTap() async {
    final user = UserDirty();
    user.byfind = !AppConfig.client.user.byfind;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsByCodeItemTap() async {
    final user = UserDirty();
    user.bycode = !AppConfig.client.user.bycode;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsByCardItemTap() async {
    final user = UserDirty();
    user.bycard = !AppConfig.client.user.bycard;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsByTeamItemTap() async {
    final user = UserDirty();
    user.byteam = !AppConfig.client.user.byteam;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsNoticeItemTap() async {
    final user = UserDirty();
    user.notice = !AppConfig.client.user.notice;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsSlientItemTap() async {
    final user = UserDirty();
    user.silent = !AppConfig.client.user.silent;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserLogoutBtnTap() {
    WidgetDialog.alert(
      context,
      body: AppLocalizations.usermeSettingsBoxLogoutHint,
      leftText: AppLocalizations.usermeSettingsBoxLogoutCancel,
      rightText: AppLocalizations.usermeSettingsBoxLogoutSure,
      rightColor: Colors.redAccent,
    ).then((value) async {
      if (value == null || !value) return;
      SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsLogoutLoading);
      final result = await AppConfig.client.userLeave();
      SmartDialog.dismiss();
      //下面操作必须进行
      AppConfig.clearUserCredentials();
      SmartDialog.showToast(result.desc);
      if (!mounted) return;
      AppRouter.pushAppLoginNormalPage(context);
    });
  }

  void _onUserUpdateListener(EasyPacket packet) {
    if (mounted) {
      setState(() {});
    }
  }
}

==> imsdk_client_flutter-0.0.11.tar.gz: lib/app/userme_settings.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart';

import 'app_config.dart';
import 'app_locale.dart';
import 'app_router.dart';
import 'widget/widget_dialog.dart';
import 'widget/widget_divider.dart';

///
///个人中心设置页
///
class UsermeSettings extends StatefulWidget {
  ///标题
  final String title;

  const UsermeSettings({Key? key, required this.title}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _UsermeSettingsState();
}

class _UsermeSettingsState extends State<UsermeSettings> {
  @override
  void initState() {
    super.initState();
    AppConfig.logDebug(['UsermeSettings.initState()']);
    AppConfig.client.setOnUserUpdateListener(_onUserUpdateListener, remove: false);
  }

  @override
  void dispose() {
    AppConfig.logDebug(['UsermeSettings.dispose()']);
    AppConfig.client.setOnUserUpdateListener(_onUserUpdateListener, remove: true);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    return Scaffold(
      appBar: _buildAppBar(themeData),
      body: _buildBody(themeData),
    );
  }

  AppBar _buildAppBar(ThemeData themeData) {
    return AppBar(
      title: Text(widget.title),
    );
  }

  Widget _buildBody(ThemeData themeData) {
    return ListView(
      physics: AppConfig.globalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserByfind, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.byfind, onChanged: (value) => _onUserSettingsByFindItemTap()),
                onTap: _onUserSettingsByFindItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserBycode, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.bycode, onChanged: (value) => _onUserSettingsByCodeItemTap()),
                onTap: _onUserSettingsByCodeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserBycard, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.bycard, onChanged: (value) => _onUserSettingsByCardItemTap()),
                onTap: _onUserSettingsByCardItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserByteam, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.byteam, onChanged: (value) => _onUserSettingsByTeamItemTap()),
                onTap: _onUserSettingsByTeamItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserNotice, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: AppConfig.client.user.notice, onChanged: (value) => _onUserSettingsNoticeItemTap()),
                onTap: _onUserSettingsNoticeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.usermeSettingsUserSlient, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: !AppConfig.client.user.silent, onChanged: (value) => _onUserSettingsSlientItemTap()),
                onTap: _onUserSettingsSlientItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    const Icon(Icons.power_settings_new_outlined, color: Colors.redAccent, size: AppConfig.iconGlobalSizeMedium),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.usermeSettingsBtnLogout, style: themeData.textTheme.subtitle1?.copyWith(color: Colors.redAccent)),
                  ],
                ),
                onTap: _onUserLogoutBtnTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  void _onUserSettingsByFindItemTap() async {
    final user = UserDirty();
    user.byfind = !AppConfig.client.user.byfind;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsByCodeItemTap() async {
    final user = UserDirty();
    user.bycode = !AppConfig.client.user.bycode;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsByCardItemTap() async {
    final user = UserDirty();
    user.bycard = !AppConfig.client.user.bycard;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsByTeamItemTap() async {
    final user = UserDirty();
    user.byteam = !AppConfig.client.user.byteam;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsNoticeItemTap() async {
    final user = UserDirty();
    user.notice = !AppConfig.client.user.notice;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserSettingsSlientItemTap() async {
    final user = UserDirty();
    user.silent = !AppConfig.client.user.silent;
    SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsSaveLoading);
    final result = await AppConfig.client.userUpdate(uid: AppConfig.client.user.id, fields: user.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onUserLogoutBtnTap() {
    WidgetDialog.alert(
      context,
      body: AppLocalizations.usermeSettingsBoxLogoutHint,
      leftText: AppLocalizations.usermeSettingsBoxLogoutCancel,
      rightText: AppLocalizations.usermeSettingsBoxLogoutSure,
      rightColor: Colors.redAccent,
    ).then((value) async {
      if (value == null || !value) return;
      SmartDialog.showLoading(msg: AppLocalizations.usermeSettingsLogoutLoading);
      final result = await AppConfig.client.userLeave();
      SmartDialog.dismiss();
      //下面操作必须进行
      AppConfig.clearUserCredentials();
      SmartDialog.showToast(result.desc);
      if (!mounted) return;
      AppRouter.pushAppLoginNormalPage(context);
    });
  }

  void _onUserUpdateListener(EasyPacket packet) {
    if (mounted) {
      setState(() {});
    }
  }
}
